@@ -24,7 +24,7 @@ fn main() {
 	let runs = 1;
 	let now = Instant::now();
 	for _ in 0..runs {
-		p.render(&stack, &mut canvas, &mut mask, size.0);
+		p.render(&stack, &mut canvas, &mut mask, size.0, size.1, 0);
 	}
 	println!("rendered {} times in {}ms.", runs, now.elapsed().as_millis());
 
